package geniusweb.references;

import java.net.URI;
import java.net.URISyntaxException;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * A URL reference to a Domain: the place where this domain is stored.
 */
public class DomainRef implements Reference {
	@JsonValue
	private URI uri;

	@JsonCreator // special: we need a URI so no @JsonProperty here
	public DomainRef(String uri) throws URISyntaxException {
		this(new URI(uri));
	}

	public DomainRef(URI url) {
		this.uri = url;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((uri == null) ? 0 : uri.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		DomainRef other = (DomainRef) obj;
		if (uri == null) {
			if (other.uri != null)
				return false;
		} else if (!uri.equals(other.uri))
			return false;
		return true;
	}

	@Override
	public URI getURI() {
		return uri;
	}

	@Override
	public String toString() {
		return "DomainRef[" + uri + "]";
	}

}
